********************************************************************************
********************************************************************************
*****************    BUILDING CONNECTIONS     **********************************
********************************************************************************
********************************************************************************


********************************************************************************
**********************************  Prepare Data Connections BOARD DIRECTORS  *************
********************************************************************************



/* Download and merge directors personal information and education history from CSMAR. 
This can be found (as long as CSMAR remains the same) in the Listed Firms and Figure Characteristics
package. Data was taken an merge from the folders inside and next with politicians information: */
save using "ConnectionsChina2008_2017_Board"

import delimited "Data-prep2007-2012.txt", varnames(1) encoding(GBK) clear
tempfile DataPrep_politicians
save `DataPrep_politicians'
import delimited "Data-prep2012-2017.txt", varnames(1) encoding(GBK) clear
append using `DataPrep_politicians'
*the following "rename" lines are needed when data is imported in txt format (not in excel)
rename politburo Politburo
rename enddate EndDate
rename birthplace_en BirthPlace_en
rename gender_en Gender_en
rename age Age
rename fullname_en FullName_en
rename degree Degree
rename universityid UniversityID
rename university_en University_en
rename admissiontime AdmissionTime
rename graduationtime GraduationTime
rename politicianid PoliticianID
rename pbrow PBrow
rename numberpb NumberPB
rename pbrow_new PBrow_new

append using "ConnectionsChina2008_2017_Board"
save "ConnectionsChina2008_2017_Board", replace

******************************************************************************************************
**********************************  Building Connections to BOARD ********************************************
******************************************************************************************************

	clear
	use "ConnectionsChina2008_2017_Board"
	
	replace UniversityID = universityid if PersonID !=.
	drop universityid
	replace Age = age if PersonID !=.
	drop age

	label var Politburo "1 if they belong to 2007-2012 politburo and 2 from 2012-2017"
	label var EndDate "for politicians this is their first year at Politburo, for CEOS fiscal year"
	label var PBrow "Values 1-39 for politicians that belonged to PB 2007-2012. Values 40-99 for those in 2012-2017 PB"
	replace PoliticianID = NumberPB
	label var PoliticianID "Number of person in PB. It is not an ID, so it doesn't uniquely identify politicians. It takes values 1-25 for the 25 politicians in PB=2 and 26-51 for PB=1"
	drop NumberPB

	destring Symbol, replace ignore("N/A") force
	
	gen top5 = 0 
	gen top10 = 0
		
/*	1.	Tsinghua University = 10143851
	2.	Peking University = 10143850
	3.	Fudan University = 10149414
	4.	Zhejiang University = 10229494
	5.	Shanghai Jiao Tong University = 10226507
	6.	University of Science and Technology of China in Hefei City = 10447347
	7.	Nanjing University = 10226737
	8.	Wuhan University = 10143869
	9.	Tongji University = 10226510
	10.	Beijing Normal University = 10228729
*/

	
	replace top5 = 1 if UniversityID == 10143851 | UniversityID == 10143850 | UniversityID == 10149414 | UniversityID == 10229494 | UniversityID == 10226507
	replace top10 = 1 if UniversityID == 10143851 | UniversityID == 10143850 | UniversityID == 10149414 | UniversityID == 10229494 | UniversityID == 10226507
	replace top10 = 1 if UniversityID == 10447347 | UniversityID == 10226737 | UniversityID == 10143869 | UniversityID == 10226510 | UniversityID == 10228729
	

	*HOW TO CODE CONNECTION
	*Let ConnEduc1 denote whether they went to the same university or not
	gen ConnEduc1=0
	gen localvar=.

	forvalues i=1/39 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	replace ConnEduc1=1 if UniversityID==localvar & EndDate<2012 & UniversityID !=.
	} 

	forvalues i=40/99 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	replace ConnEduc1=1 if UniversityID==localvar & EndDate>=2012 & UniversityID !=.
	}
	drop localvar



	*Let ConnEduc3 denote whether they attended to the same university, same program and at the same time
	* AGE
	gen ConnEduc3=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2007
	gen ConnPBrow = 0
	
	forvalues i=1/39 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	sum Age if PBrow==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if PBrow==`i'
	replace localvar2=r(min)
	replace ConnEduc3=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 & EndDate<2012 & Age !=. & minage !=. & maxage !=. & UniversityID !=.
	replace ConnPBrow = `i' if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 & EndDate<2012 & Age !=. & minage !=. & maxage !=. & UniversityID !=.
	} 
	replace localyear=EndDate-2012
	forvalues i=40/99 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	sum Age if PBrow==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if PBrow==`i'
	replace localvar2=r(min)
	replace ConnEduc3=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 & EndDate>=2012 & Age !=. & minage !=. & maxage !=. & UniversityID !=.
	replace ConnPBrow = `i' if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 & EndDate>=2012 & Age !=. & minage !=. & maxage !=. & UniversityID !=. 
	}
	drop localvar localvar2 maxage minage localyear
	
	* GRADUATION TIME
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	
	forvalues i=1/39 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	sum GraduationTime if PBrow==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	sum Degree if PBrow==`i'
	replace localvar2=r(min)
	replace ConnEduc3=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar & Degree==localvar2 & EndDate<2012 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	replace ConnPBrow=`i' if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar & Degree==localvar2 & EndDate<2012 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	gen D_ConnPBrow`i' = .
	replace D_ConnPBrow`i' = 1 if ConnPBrow==`i'
	} 
	replace localyear=EndDate-2012
	forvalues i=40/99 {
	sum UniversityID if PBrow==`i'
	replace localvar=r(min)
	sum GraduationTime if PBrow==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	sum Degree if PBrow==`i'
	replace localvar2=r(min)
	replace ConnEduc3=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar & Degree==localvar2 & EndDate>=2012 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	replace ConnPBrow=`i' if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar & Degree==localvar2 & EndDate>=2012 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	gen D_ConnPBrow`i' = .
	replace D_ConnPBrow`i' = 1 if ConnPBrow==`i'
	}
	drop localvar localvar2 maxgrad mingrad localyear
	
	
	
	* CONNECTIONS TO DISGRACED MEMBERS:
	* (1) BEING CONNECTED TO ZHOU YONGKANG (in the PB from 2007-2012, arrested and expelled in 2014)
	gen disgrace_zhou=.
	replace disgrace_zhou=1 if  FullName_en=="Zhou Yongkang" 
	sort  disgrace_zhou EndDate
	gen disgrace_zhou_id=_n if disgrace_zhou==1
	

	gen ConnEduc3_disgrace_zhou=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2007
	
	forvalues i=1/2 {
	sum UniversityID if disgrace_zhou_id==`i'
	replace localvar=r(min)
	sum Age if disgrace_zhou_id==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if disgrace_zhou_id==`i'
	replace localvar2=r(min)
	replace ConnEduc3_disgrace_zhou=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 
	} 
	
	drop localvar localvar2 maxage minage localyear
	
	*With GRADUATION TIME to Zhou Yongkang : Here we are considering an interval of 4 years
	
	gen ConnEduc3_grad_disgrace_zhou=0
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	forvalues i=1/2 {
	sum UniversityID if disgrace_zhou_id==`i'
	replace localvar=r(min)
	sum GraduationTime if disgrace_zhou_id==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	replace ConnEduc3_grad_disgrace_zhou=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar  & Degree==localvar2 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	}
	drop mingrad maxgrad localvar localvar2 localyear 
	
	* ConnEduc3_zhou_full is dummy that states whether a member was connected to zhou using both age and graduation time
	gen ConnEduc3_zhou_full=0
	replace ConnEduc3_zhou_full=1 if ConnEduc3_grad_disgrace_zhou==1 | ConnEduc3_disgrace_zhou==1
	
	
	
	* (2) BEING CONNECTED TO BO XILAI (2007-2012, expelled in september 2012 from the PCC, charged with corruption in 2013)
	gen disgrace_bo=.
	replace disgrace_bo=1 if FullName_en=="Bo Xilai"
	sort  disgrace_bo EndDate
	gen disgrace_bo_id=_n if disgrace_bo==1
	

	gen ConnEduc3_disgrace_bo=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2007
	
	forvalues i=1/3 {
	sum UniversityID if disgrace_bo_id==`i'
	replace localvar=r(min)
	sum Age if disgrace_bo_id==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if disgrace_bo_id==`i'
	replace localvar2=r(min)
	replace ConnEduc3_disgrace_bo=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 
	} 
	
	drop localvar localvar2 maxage minage localyear
	
	*With GRADUATION TIME to Bo Xilai : Here we are considering an interval of 4 years
	
	gen ConnEduc3_grad_disgrace_bo=0
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	forvalues i=1/3 {
	sum UniversityID if disgrace_bo_id==`i'
	replace localvar=r(min)
	sum GraduationTime if disgrace_bo_id==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	replace ConnEduc3_grad_disgrace_bo=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar  & Degree==localvar2 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	}
	drop mingrad maxgrad localvar localvar2 localyear 
	
	* ConnEduc3_bo_full is dummy that states whether a member was connected to Bo using both age and graduation time
	gen ConnEduc3_bo_full=0
	replace ConnEduc3_bo_full=1 if ConnEduc3_grad_disgrace_bo==1 | ConnEduc3_disgrace_bo==1
	
	
	* (3) BEING CONNECTED TO SUN ZHENGCAI (he was in th PB from 2012-2017 and in 2017 he was expelled)
	gen disgrace_sun=.
	replace disgrace_sun=1 if FullName_en=="Sun Zhengcai, until 2017; expelled"
	sort  disgrace_sun EndDate
	gen disgrace_sun_id=_n if disgrace_sun==1
	

	gen ConnEduc3_disgrace_sun=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2012
	
	forvalues i=1/3 {
	sum UniversityID if disgrace_sun_id==`i'
	replace localvar=r(min)
	sum Age if disgrace_sun_id==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if disgrace_sun_id==`i'
	replace localvar2=r(min)
	replace ConnEduc3_disgrace_sun=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 
	} 
	
	drop localvar localvar2 maxage minage localyear
	
	*With GRADUATION TIME to Sun Zhengcai : Here we are considering an interval of 4 years
	
	gen ConnEduc3_grad_disgrace_sun=0 
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	forvalues i=1/3 {
	sum UniversityID if disgrace_sun_id==`i'
	replace localvar=r(min)
	sum GraduationTime if disgrace_sun_id==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	replace ConnEduc3_grad_disgrace_sun=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar  & Degree==localvar2 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	}
	drop mingrad maxgrad localvar localvar2 localyear 
	
	* ConnEduc3_sun_full is dummy that states whether a member was connected to Sun using both age and graduation time
	gen ConnEduc3_sun_full=0
	replace ConnEduc3_sun_full=1 if ConnEduc3_grad_disgrace_sun==1 | ConnEduc3_disgrace_sun==1
	
	
	
	* (4) BEING CONNECTED TO XU CAIHOU 徐才厚 (in the PB from 2007-2012, expelled from the Party. Died in 2015)
	gen disgrace_xu=.
	replace disgrace_xu=1 if  FullName_en=="Xu Caihou" 
	sort  disgrace_xu EndDate
	gen disgrace_xu_id=_n if disgrace_xu==1
	
	
	gen ConnEduc3_disgrace_xu=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2007
	
	forvalues i=1/1 {
	sum UniversityID if disgrace_xu_id==`i'
	replace localvar=r(min)
	sum Age if disgrace_xu_id==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if disgrace_xu_id==`i'
	replace localvar2=r(min)
	replace ConnEduc3_disgrace_xu=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 
	} 
	
	drop localvar localvar2 maxage minage localyear
	
	*With GRADUATION TIME to Xu Caihou : Here we are considering an interval of 4 years
	
	gen ConnEduc3_grad_disgrace_xu=0
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	forvalues i=1/1 {
	sum UniversityID if disgrace_xu_id==`i'
	replace localvar=r(min)
	sum GraduationTime if disgrace_xu_id==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	replace ConnEduc3_grad_disgrace_xu=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar  & Degree==localvar2 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	}
	drop mingrad maxgrad localvar localvar2 localyear 
	
	* ConnEduc3_xu_full is dummy that states whether a member was connected to zhou using both age and graduation time
	gen ConnEduc3_xu_full=0
	replace ConnEduc3_xu_full=1 if ConnEduc3_grad_disgrace_xu==1 | ConnEduc3_disgrace_xu==1 
	
	
	* (5) BEING CONNECTED TO GUO BOXIONG (in the PB from 2007-2012, arrested)
	gen disgrace_guo=.
	replace disgrace_guo=1 if  FullName_en=="Guo Boxiong" 
	sort  disgrace_guo EndDate
	gen disgrace_guo_id=_n if disgrace_guo==1
	
	
	gen ConnEduc3_disgrace_guo=0
	gen localvar=.
	gen localvar2=.
	gen minage=.
	gen maxage=.
	gen localyear=EndDate-2007
	
	forvalues i=1/2 {
	sum UniversityID if disgrace_guo_id==`i'
	replace localvar=r(min)
	sum Age if disgrace_guo_id==`i'
	replace minage=r(min) -4 +localyear
	replace maxage=r(min) +4 +localyear
	sum Degree if disgrace_guo_id==`i'
	replace localvar2=r(min)
	replace ConnEduc3_disgrace_guo=1 if Age<=maxage & minage<=Age & UniversityID==localvar & Degree==localvar2 
	} 
	
	drop localvar localvar2 maxage minage localyear
	
	*With GRADUATION TIME to Guo Boxiong : Here we are considering an interval of 4 years
	
	gen ConnEduc3_grad_disgrace_guo=0
	gen localvar=.
	gen localvar2=.
	gen mingrad=.
	gen maxgrad=.
	gen localyear=EndDate-2007
	forvalues i=1/2 {
	sum UniversityID if disgrace_guo_id==`i'
	replace localvar=r(min)
	sum GraduationTime if disgrace_guo_id==`i'
	replace mingrad=r(min) -4 +localyear
	replace maxgrad=r(min) +4 +localyear
	replace ConnEduc3_grad_disgrace_guo=1 if GraduationTime<=maxgrad & mingrad<=GraduationTime & UniversityID==localvar  & Degree==localvar2 & GraduationTime !=. & mingrad !=. & maxgrad !=. & UniversityID !=.
	}
	drop mingrad maxgrad localvar localvar2 localyear 
	
	* ConnEduc3_guo_full is dummy that states whether a member was connected to zhou using both age and graduation time
	gen ConnEduc3_guo_full=0
	replace ConnEduc3_guo_full=1 if ConnEduc3_grad_disgrace_guo==1 | ConnEduc3_disgrace_guo==1 
	
	
	gen ConnEduc3_disgrace=0
	replace ConnEduc3_disgrace=1 if ConnEduc3_disgrace_sun==1 | ConnEduc3_disgrace_bo==1 | ConnEduc3_disgrace_zhou==1

	gen ConnEduc3_5disgrace=0  /* Here I do it adding the 2 additional fallen in disgrace*/
	replace ConnEduc3_5disgrace=1 if ConnEduc3_disgrace_sun==1 | ConnEduc3_disgrace_bo==1 | ConnEduc3_disgrace_zhou==1 | ConnEduc3_disgrace_xu==1 | ConnEduc3_disgrace_guo==1 

	
	*Next, I take into account both graduation time and age connections:

	gen ConnEduc3_disgrace_full=0
	replace ConnEduc3_disgrace_full=1 if ConnEduc3_sun_full==1 | ConnEduc3_bo_full==1 | ConnEduc3_zhou_full==1
	
	
	gen ConnEduc3_disgrace_5full=0 /* Here I do it adding the 2 additional fallen in disgrace*/
	replace ConnEduc3_disgrace_5full=1 if ConnEduc3_sun_full==1 | ConnEduc3_bo_full==1 | ConnEduc3_zhou_full==1 | ConnEduc3_xu_full==1 | ConnEduc3_guo_full==1
	

		
	*Now let's check the number of Board directors connected per company each year

	* CREATE A VBLE FOR EACH PERSON ID THAT SUMMARIZES WHETHER HE HAS A CONNECTION OR NOT 
	rename Symbol Stkcd 

	gen DummyConnEduc1 = 0
		label var DummyConnEduc1 "1 if connected to PB politician by university, 0 otw"
	gen DummyConnEduc3 = 0
		label var DummyConnEduc3 "1 if connected to PB politician by university & year & degree, 0 otw"
	
	
	
	*same for the disgraced (/*The ones with _full at the end consider both age and graduation time*/)

	gen DummyConnEduc3_zhou = 0
	gen DummyConnEduc3_zhou_full = 0
		label var DummyConnEduc3_zhou "1 if connected to Zhou Yongkang politician by university & year & degree, 0 otw"
		
	gen DummyConnEduc3_bo = 0
	gen DummyConnEduc3_bo_full = 0
		label var DummyConnEduc3_bo "1 if connected to Bo Xilai  politician by university & year & degree, 0 otw"

	gen DummyConnEduc3_sun = 0
	gen DummyConnEduc3_sun_full = 0
		label var DummyConnEduc3_sun "1 if connected to Sun Zhengcai  politician by university & year & degree, 0 otw"
		

	gen DummyConnEduc3_xu = 0
	gen DummyConnEduc3_xu_full = 0
		label var DummyConnEduc3_xu "1 if connected to Xu Caihou  politician by university & year & degree, 0 otw"
			
	gen DummyConnEduc3_guo = 0
	gen DummyConnEduc3_guo_full = 0
		label var DummyConnEduc3_guo "1 if connected to Guo Boxiong  politician by university & year & degree, 0 otw"
			
		
	gen DummyConnEduc3_disgrace = 0
	gen DummyConnEduc3_5disgrace = 0
	gen DummyConnEduc3_disgrace_full = 0
	gen DummyConnEduc3_disgrace_5full = 0	/*For the 2 added fallen politicians*/
		label var DummyConnEduc3_disgrace "1 if connected to at least one disgraced  politician by university & year & degree, 0 otw"
		
	
	
	
	sort Stkcd EndDate PersonID
	by Stkcd EndDate PersonID: replace DummyConnEduc1 = sum(ConnEduc1)
	by Stkcd EndDate PersonID: replace DummyConnEduc3 = sum(ConnEduc3)

	sort Stkcd EndDate PersonID
	by Stkcd EndDate PersonID: egen MaxNumberConn1 = max(DummyConnEduc1)
	by Stkcd EndDate PersonID: egen MaxNumberConn3 = max(DummyConnEduc3)

	sort Stkcd EndDate PersonID
	replace DummyConnEduc1 = 1 if MaxNumberConn1>0
	replace DummyConnEduc3 = 1 if MaxNumberConn3>0

	drop MaxNumberConn1  MaxNumberConn3 ConnEduc1  ConnEduc3 

	
	
	*same for disgraced:

	by Stkcd EndDate PersonID: replace DummyConnEduc3_zhou = sum(ConnEduc3_disgrace_zhou)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_zhou_full = sum(ConnEduc3_zhou_full)

	by Stkcd EndDate PersonID: replace DummyConnEduc3_bo = sum(ConnEduc3_disgrace_bo)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_bo_full = sum(ConnEduc3_bo_full)
		
	by Stkcd EndDate PersonID: replace DummyConnEduc3_sun = sum(ConnEduc3_disgrace_sun)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_sun_full = sum(ConnEduc3_sun_full)
	
	by Stkcd EndDate PersonID: replace DummyConnEduc3_xu = sum(ConnEduc3_disgrace_xu)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_xu_full = sum(ConnEduc3_xu_full)
	
	by Stkcd EndDate PersonID: replace DummyConnEduc3_guo = sum(ConnEduc3_disgrace_guo)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_guo_full = sum(ConnEduc3_guo_full)
	
	by Stkcd EndDate PersonID: replace DummyConnEduc3_disgrace = sum(ConnEduc3_disgrace)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_5disgrace = sum(ConnEduc3_5disgrace)	
	by Stkcd EndDate PersonID: replace DummyConnEduc3_disgrace_full = sum(ConnEduc3_disgrace_full)
	by Stkcd EndDate PersonID: replace DummyConnEduc3_disgrace_5full = sum(ConnEduc3_disgrace_5full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_zhou = max(DummyConnEduc3_zhou)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_zhou_full = max(DummyConnEduc3_zhou_full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_bo = max(DummyConnEduc3_bo)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_bo_full = max(DummyConnEduc3_bo_full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_sun = max(DummyConnEduc3_sun)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_sun_full = max(DummyConnEduc3_sun_full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_xu = max(DummyConnEduc3_xu)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_xu_full = max(DummyConnEduc3_xu_full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_guo = max(DummyConnEduc3_guo)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_guo_full = max(DummyConnEduc3_guo_full)
	
	by Stkcd EndDate PersonID: egen MaxNumberConn3_disgrace = max(DummyConnEduc3_disgrace)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_5disgrace = max(DummyConnEduc3_5disgrace)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_disgrace_full = max(DummyConnEduc3_disgrace_full)
	by Stkcd EndDate PersonID: egen MaxNumberConn3_disgrace_5full = max(DummyConnEduc3_disgrace_5full)


	replace DummyConnEduc3_zhou = 1 if MaxNumberConn3_zhou>0
	replace DummyConnEduc3_zhou_full = 1 if MaxNumberConn3_zhou_full>0
	
	replace DummyConnEduc3_bo = 1 if MaxNumberConn3_bo>0
	replace DummyConnEduc3_bo_full = 1 if MaxNumberConn3_bo_full>0

	replace DummyConnEduc3_sun = 1 if MaxNumberConn3_sun>0
	replace DummyConnEduc3_sun_full = 1 if MaxNumberConn3_sun_full>0
	
	replace DummyConnEduc3_xu = 1 if MaxNumberConn3_xu>0
	replace DummyConnEduc3_xu_full = 1 if MaxNumberConn3_xu_full>0
	
	replace DummyConnEduc3_guo = 1 if MaxNumberConn3_guo>0
	replace DummyConnEduc3_guo_full = 1 if MaxNumberConn3_guo_full>0
	
	replace DummyConnEduc3_disgrace = 1 if MaxNumberConn3_disgrace>0
	replace DummyConnEduc3_disgrace_full = 1 if MaxNumberConn3_disgrace_full>0
	replace DummyConnEduc3_5disgrace = 1 if MaxNumberConn3_5disgrace>0
	replace DummyConnEduc3_disgrace_5full = 1 if MaxNumberConn3_disgrace_5full>0
	

	
	drop MaxNumberConn3_zhou MaxNumberConn3_bo MaxNumberConn3_sun MaxNumberConn3_disgrace   
	drop MaxNumberConn3_zhou_full MaxNumberConn3_bo_full MaxNumberConn3_sun_full MaxNumberConn3_disgrace_full
	drop MaxNumberConn3_xu_full MaxNumberConn3_xu MaxNumberConn3_guo MaxNumberConn3_guo_full MaxNumberConn3_5disgrace MaxNumberConn3_disgrace_5full
	drop ConnEduc3_zhou_full ConnEduc3_bo_full ConnEduc3_sun_full ConnEduc3_disgrace_full ConnEduc3_xu_full ConnEduc3_guo_full ConnEduc3_disgrace_5full ConnEduc3_5disgrace

	
		
	by Stkcd EndDate PersonID: egen maxtop5 = sum(top5)
	by Stkcd EndDate PersonID: egen maxtop10 = sum(top10)
	
	replace top5=1 if maxtop5>0
	replace top10=1 if maxtop10>0
	
	drop maxtop5 maxtop10

*** Create variables containing number of connections per firm & year ***
	
	duplicates drop EndDate Stkcd PersonID, force


	gen NumConnEduc1 = 0
	label var NumConnEduc1 "Number of directors connected to PB politician by university, 0 otw"
	gen NumConnEduc3 = 0
	label var NumConnEduc3 "Number of drs connected to PB politician by univ & yr & degree, 0 otw"


	*Same for disgraced:
	
	gen NumConnEduc3_zhou = 0
	gen NumConnEduc3_zhou_full = 0
	label var NumConnEduc3_zhou "Number of directors connected to Zhou Yongkang politician by university & year & degree, 0 otw"

	gen NumConnEduc3_bo = 0
	gen NumConnEduc3_bo_full = 0
	label var NumConnEduc3_bo "Number of directors connected to Bo Xilai politician by university & year & degree, 0 otw"

	gen NumConnEduc3_sun = 0
	gen NumConnEduc3_sun_full = 0
	label var NumConnEduc3_sun "Number of directors connected to Sun Zhengcai politician by university & year & degree, 0 otw"
	
	gen NumConnEduc3_xu = 0
	gen NumConnEduc3_xu_full = 0
	label var NumConnEduc3_xu "Number of directors connected to Xu Caihou politician by university & year & degree, 0 otw"
	
	gen NumConnEduc3_guo = 0
	gen NumConnEduc3_guo_full = 0
	label var NumConnEduc3_guo "Number of directors connected to Guo Boxiong politician by university & year & degree, 0 otw"
	
	gen NumConnEduc3_disgrace = 0
	gen NumConnEduc3_5disgrace = 0
	gen NumConnEduc3_disgrace_full = 0
	gen NumConnEduc3_disgrace_5full = 0
	label var NumConnEduc3_disgrace "Number of directors connected to disgrace politician by university & year & degree, 0 otw"

	
	
	sort Stkcd EndDate
	by Stkcd EndDate: replace NumConnEduc1 = sum(DummyConnEduc1)
	by Stkcd EndDate: replace NumConnEduc3 = sum(DummyConnEduc3)

	sort Stkcd EndDate
	by Stkcd EndDate: egen MaxNumConnEduc1 = max(NumConnEduc1)
	by Stkcd EndDate: egen MaxNumConnEduc3 = max(NumConnEduc3)

	sort Stkcd EndDate
	replace NumConnEduc1 = MaxNumConnEduc1
	replace NumConnEduc3 = MaxNumConnEduc3

	drop MaxNumConnEduc1  MaxNumConnEduc3
	
	
	*Same for disgraced:


	by Stkcd EndDate: replace NumConnEduc3_zhou = sum(DummyConnEduc3_zhou)
	by Stkcd EndDate: replace NumConnEduc3_zhou_full = sum(DummyConnEduc3_zhou_full)

	by Stkcd EndDate: replace NumConnEduc3_bo = sum(DummyConnEduc3_bo)
	by Stkcd EndDate: replace NumConnEduc3_bo_full = sum(DummyConnEduc3_bo_full)

	by Stkcd EndDate: replace NumConnEduc3_sun = sum(DummyConnEduc3_sun)
	by Stkcd EndDate: replace NumConnEduc3_sun_full = sum(DummyConnEduc3_sun_full)
	
	by Stkcd EndDate: replace NumConnEduc3_guo = sum(DummyConnEduc3_guo)
	by Stkcd EndDate: replace NumConnEduc3_guo_full = sum(DummyConnEduc3_guo_full)
	
	by Stkcd EndDate: replace NumConnEduc3_disgrace = sum(DummyConnEduc3_disgrace)
	by Stkcd EndDate: replace NumConnEduc3_5disgrace = sum(DummyConnEduc3_5disgrace)	
	by Stkcd EndDate: replace NumConnEduc3_disgrace_full = sum(DummyConnEduc3_disgrace_full)
	by Stkcd EndDate: replace NumConnEduc3_disgrace_5full = sum(DummyConnEduc3_disgrace_5full)


	by Stkcd EndDate: egen MaxNumConnEduc3_zhou = max(NumConnEduc3_zhou)
	by Stkcd EndDate: egen MaxNumConnEduc3_zhou_full = max(NumConnEduc3_zhou_full)
	
	by Stkcd EndDate: egen MaxNumConnEduc3_bo = max(NumConnEduc3_bo)
	by Stkcd EndDate: egen MaxNumConnEduc3_bo_full = max(NumConnEduc3_bo_full)

	by Stkcd EndDate: egen MaxNumConnEduc3_sun = max(NumConnEduc3_sun)
	by Stkcd EndDate: egen MaxNumConnEduc3_sun_full = max(NumConnEduc3_sun_full)

	by Stkcd EndDate: egen MaxNumConnEduc3_xu = max(NumConnEduc3_xu)
	by Stkcd EndDate: egen MaxNumConnEduc3_xu_full = max(NumConnEduc3_xu_full)
	
	by Stkcd EndDate: egen MaxNumConnEduc3_guo = max(NumConnEduc3_guo)
	by Stkcd EndDate: egen MaxNumConnEduc3_guo_full = max(NumConnEduc3_guo_full)

	by Stkcd EndDate: egen MaxNumConnEduc3_disgrace = max(NumConnEduc3_disgrace)
	by Stkcd EndDate: egen MaxNumConnEduc3_5disgrace = max(NumConnEduc3_5disgrace)
	by Stkcd EndDate: egen MaxNumConnEduc3_disgrace_full = max(NumConnEduc3_disgrace_full)
	by Stkcd EndDate: egen MaxNumConnEduc3_disgrace_5full = max(NumConnEduc3_disgrace_5full)
	
	replace NumConnEduc3_zhou = MaxNumConnEduc3_zhou
	replace NumConnEduc3_zhou_full = MaxNumConnEduc3_zhou_full

	replace NumConnEduc3_bo = MaxNumConnEduc3_bo
	replace NumConnEduc3_bo_full = MaxNumConnEduc3_bo_full
	
	replace NumConnEduc3_sun = MaxNumConnEduc3_sun
	replace NumConnEduc3_sun_full = MaxNumConnEduc3_sun_full
	
	replace NumConnEduc3_xu = MaxNumConnEduc3_xu
	replace NumConnEduc3_xu_full = MaxNumConnEduc3_xu_full
	
	replace NumConnEduc3_guo = MaxNumConnEduc3_guo
	replace NumConnEduc3_guo_full = MaxNumConnEduc3_guo_full
	

	replace NumConnEduc3_disgrace = MaxNumConnEduc3_disgrace
	replace NumConnEduc3_5disgrace = MaxNumConnEduc3_5disgrace
	replace NumConnEduc3_disgrace_full = MaxNumConnEduc3_disgrace_full
	replace NumConnEduc3_disgrace_5full = MaxNumConnEduc3_disgrace_5full
	
	drop MaxNumConnEduc3_zhou MaxNumConnEduc3_bo MaxNumConnEduc3_sun MaxNumConnEduc3_disgrace
	drop MaxNumConnEduc3_zhou_full MaxNumConnEduc3_bo_full MaxNumConnEduc3_sun_full MaxNumConnEduc3_disgrace_full MaxNumConnEduc3_xu_full MaxNumConnEduc3_guo_full MaxNumConnEduc3_disgrace_5full 
	drop MaxNumConnEduc3_xu MaxNumConnEduc3_guo MaxNumConnEduc3_5disgrace
	
	

* Board variables
	
	by Stkcd EndDate: egen boardsize = count(PersonID)
	by Stkcd EndDate: egen boardmean_age = mean(Age)
	by Stkcd EndDate: egen dualboard = sum(isduality)
		replace dualboard = 1 if dualboard >1
	by Stkcd EndDate: egen busydir = mean(director_totco)
		label var busydir "mean number of positions in other companies per director"
	by Stkcd EndDate: egen board_indratio = sum(isidirecotr)
		replace board_indratio = board_indratio / boardsize
			label var board_indratio "ratio of independent directors in the firm"
	encode gender, gen(gender_encoded)
	gen gender_dummy = gender == "男"
	replace gender_dummy = . if missing(gender)
	by Stkcd EndDate: egen board_gender = sum(gender_dummy)
		replace board_gender = board_gender / boardsize
		label var board_gender "ratio of male to total board directors"
	

	gen conn_top5 = 1 if DummyConnEduc3==1 & top5==1
	gen conn_top10 = 1 if DummyConnEduc3==1 & top10==1

	drop DummyConnEduc1  DummyConnEduc3 gainconn
	
	by Stkcd EndDate: egen number_drs_top5 = sum(top5)
	by Stkcd EndDate: egen number_drs_top10 = sum(top10)
	
	by Stkcd EndDate: egen number_conns_top5 = sum(conn_top5)
	by Stkcd EndDate: egen number_conns_top10 = sum(conn_top10)
		
	duplicates drop Stkcd EndDate, force
	
	gen dummy_top5 = 0
		replace dummy_top5 = 1 if number_drs_top5 > 0
	gen dummy_top10 = 0
		replace dummy_top10 = 1 if number_drs_top10 > 0

	gen dummy_conn_top5 = 0
		replace dummy_conn_top5 = 1 if number_conns_top5 > 0
	gen dummy_conn_top10 = 0
		replace dummy_conn_top10 = 1 if number_conns_top10 > 0


	*** Create other Connection variable by firm and year (not taking into account the number of directors connected) ***

	gen DummyConnEduc1 = 0
	replace DummyConnEduc1 = 1 if NumConnEduc1 > 0
	label var DummyConnEduc1 "1 if at least one director connected to PB politician by university, 0 otw"
	gen DummyConnEduc3 = 0
	replace DummyConnEduc3 = 1 if NumConnEduc3 > 0
	label var DummyConnEduc3 "1 if at least one dr connected to PB politician by univ & yr & degree, 0 otw"

	
	*Same for disgraced:

	replace DummyConnEduc3_zhou = 1 if NumConnEduc3_zhou > 0
	replace DummyConnEduc3_zhou_full = 1 if NumConnEduc3_zhou_full > 0
	

	replace DummyConnEduc3_bo = 1 if NumConnEduc3_bo > 0
	replace DummyConnEduc3_bo_full = 1 if NumConnEduc3_bo_full > 0
	

	replace DummyConnEduc3_sun = 1 if NumConnEduc3_sun > 0
	replace DummyConnEduc3_sun_full = 1 if NumConnEduc3_sun_full > 0

	replace DummyConnEduc3_xu = 1 if NumConnEduc3_xu > 0
	replace DummyConnEduc3_xu_full = 1 if NumConnEduc3_xu_full > 0
	
	replace DummyConnEduc3_guo = 1 if NumConnEduc3_guo > 0
	replace DummyConnEduc3_guo_full = 1 if NumConnEduc3_guo_full > 0
	
	replace DummyConnEduc3_disgrace = 1 if NumConnEduc3_disgrace > 0
	replace DummyConnEduc3_5disgrace = 1 if NumConnEduc3_5disgrace > 0
	replace DummyConnEduc3_disgrace_full = 1 if NumConnEduc3_disgrace_full > 0
	replace DummyConnEduc3_disgrace_5full = 1 if NumConnEduc3_disgrace_5full > 0
	
	
	
	
	gen RatioNumConnEduc1 = NumConnEduc1 / boardsize
	gen RatioNumConnEduc3 = NumConnEduc3 / boardsize

	rename Stkcd id_com
	rename EndDate year

	drop if Politburo == 1 | Politburo == 2

	drop Politburo PBrow PoliticianID PersonID birthplacecity gender Age fullname Degree UniversityID University_en AdmissionTime GraduationTime birthplacecity nationality nativeplace natareacode birthplace birareacode profession paidsign totalsalary allowance sharend ismtmt tmtp ismtb ctb isidirecotr isduality funback oveseaback fgo fgo_institp fgo_servists fgo_instilv academic finback iscocurp otherco othercotype director_totco director_listco stkcd_director major

		xtset id_com year
		gen LRatioNumConnEduc1 = L.RatioNumConnEduc1
		gen LRatioNumConnEduc3 = L.RatioNumConnEduc3
		
		gen LNumConnEduc1 = L.NumConnEduc1
		gen LNumConnEduc3 = L.NumConnEduc3

		gen Lnumber_conns_top5 = L.number_conns_top5
		gen Lnumber_conns_top10 = L.number_conns_top10
		
		gen Ldummy_conn_top5 = 0
		replace Ldummy_conn_top5 = 1 if Lnumber_conns_top5 > 0
		gen Ldummy_conn_top10 = 0
		replace Ldummy_conn_top10 = 1 if Lnumber_conns_top10 > 0
		 
		gen Ldummy_top5 = L.dummy_top5
		replace Ldummy_top5 = 0 if missing(Ldummy_top5)
		gen Ldummy_top10 = L.dummy_top10
		replace Ldummy_top10 = 0 if missing(Ldummy_top10)


	save "ConnectionsChina_Board", replace
	
********************************************************************************
********************************************************************************
*********************** CREATING ETCs ******************************************
********************************************************************************
********************************************************************************


/* selling expense */
	*import delimited "ETCdatafromCSMAR.txt", varnames(1) encoding(UTF-16) clear
	*ETC data can be found in CSMAR in the financial footnotes (only available in Chinese)
	ren fn05001 item
	drop if strmatch(item,"*合计*") /* drop the  */
	ren stkcd companyid
	keep if strmatch(accper,"*-12-31*")  /* only keep annual report (all firms' fiscal year end at December 31 in China) */
	gen year=real(substr(accper,1,4))
	drop accper
	keep if typrep==1 /* choose the Consolidated Statement */
	keep if sgnyea==1 /* choose the expense happend in current year */
	/* define the category */
		gen 业务招待费=. /* Business Entertainment Fee */
		label var 业务招待费   "Business Entertainment Fee "
		foreach w in 交际 应酬 招待 交际 业务活动 {
		replace 业务招待费=1 if strmatch(item,"*`w'*")
		}
		gen 差旅费=.  /*travel and transportation fee */
		label var 差旅费   "Travel and Transportation Fee"
		foreach w in 差旅   交通 {
		replace 差旅费=1 if strmatch(item,"*`w'*")
		}
		gen 通讯费=.  /* communication fee */
		label var 通讯费   "Communication fee"
		foreach w in 网络通讯 邮电费 电话费 网络费 邮寄费 电信费 通讯  {
		replace 通讯费=1 if strmatch(item,"*`w'*")
		}
		gen 办公费=. /* administrative expenses */
		label var 办公费   "Administrative expenses"
		foreach w in 行政办公费 办公消耗 办公场所费 办公宣传 办公费{
		replace 办公费=1 if strmatch(item,"*`w'*")
		}
		gen 会议费=. /* conference fee */
		label var 会议费   "Conference fee "
		foreach w in 会务 会议 {
		replace  会议费=1 if strmatch(item,"*`w'*")
		}
		gen 出国培训费=. /* Oversea Training Fee */
		label var 出国培训费   "Oversea Training Fee"
		foreach w in 涉外 出国 {
		replace 出国培训费=1 if strmatch(item,"*`w'*")
		}
		gen 三会费=.  /* Meeting fee related to director board, supervisor board, shareholder */
		label var 三会费   "Board Meeting fee"
		foreach w in 董事会 监事会 股东大会 {
		replace 三会费=1 if strmatch(item,"*`w'*")
		}
		gen 小车费=. /* car expense */
		label var 小车费   "Car expense"
		foreach w in 汽车费用 车辆费 公务用车费 车内交通 汽车及运杂 车费 公司车辆费 汽车及交通费 {
		replace 小车费=1 if  strmatch(item,"*`w'*")
		}

	egen ETC1=rowtotal(业务招待费 差旅费)
	egen ETC2=rowtotal(业务招待费 差旅费 小车费)
	egen ETC3=rowtotal(业务招待费 差旅费 通讯费 办公费 会议费 出国培训费  三会费 小车费)
	foreach w in ETC1 ETC2 ETC3 {
	replace `w'=1 if `w'>1
	bysort companyid year `w': egen s`w'=sum(fn05002)
	}
	keep if ETC1==1
	keep companyid year sETC1 sETC2 sETC3
	ren s* selling_*
	duplicates drop
	label var selling_ETC1   "Business Entertainment Fee  + Travel and Transportation Fee"
	label var selling_ETC2   "Business Entertainment Fee  + Travel and Transportation Fee+ Car Expense "
	label var selling_ETC3   "Total possible corrpution"
	save selling.dta,replace
/* Admnistrative expsense */
	import delimited "FN_Fn052.txt", varnames(1) encoding(UTF-16) clear
	ren fn05201 item
	drop if strmatch(item,"*合计*")
	ren stkcd companyid
	keep if strmatch(accper,"*-12-31*")
	gen year=real(substr(accper,1,4))
	drop accper
	keep if typrep==1
	keep if sgnyea==1
	gen 差旅费=.
	foreach w in 差旅 交通差旅 {
	replace 差旅费=1 if strmatch(item,"*`w'*")
	}

	gen 通讯费=.
	foreach w in 邮递 网络通讯 邮电  电话费 网络费 邮寄费 电信费 通讯  {
	replace 通讯费=1 if strmatch(item,"*`w'*")
	}
	gen 办公费=.
	foreach w in 行政办公费 办公消耗 办公场所费 办公宣传 办公费{
	replace 办公费=1 if strmatch(item,"*`w'*")
	}
	gen 会议费=.
	foreach w in 会务 会议 {
	replace  会议费=1 if strmatch(item,"*`w'*")
	}
	gen 出国培训费=.
	foreach w in 涉外 出国 {
	replace 出国培训费=1 if strmatch(item,"*`w'*")
	}
	gen 业务招待费=.
	foreach w in 交际 应酬 招待 交际 业务活动 {
	replace 业务招待费=1 if strmatch(item,"*`w'*")
	}
	gen 三会费=.
	foreach w in 董事会 监事会 股东大会 {
	replace 三会费=1 if strmatch(item,"*`w'*")
	}
	gen 小车费=.
	foreach w in 汽车费用 车辆费 公务用车费 车内交通 汽车及运杂 车费 公司车辆费 汽车及交通费 {
	replace 小车费=1 if  strmatch(item,"*`w'*")
	}
	egen ETC1=rowtotal(业务招待费 差旅费)
	egen ETC2=rowtotal(业务招待费 差旅费 小车费)
	egen ETC3=rowtotal(业务招待费 差旅费 通讯费 办公费 会议费 出国培训费  三会费 小车费)
	foreach w in ETC1 ETC2 ETC3 {
	replace `w'=1 if `w'>1
	bysort companyid year `w': egen s`w'=sum(fn05202)
	}
	keep if ETC1==1
	keep companyid year sETC1 sETC2 sETC3
	ren s* admin_*
	duplicates drop
	label var admin_ETC1   "Business Entertainment Fee  + Travel and Transportation Fee"
	label var admin_ETC2   "Business Entertainment Fee  + Travel and Transportation Fee+ Car Expense "
	label var admin_ETC3   "Total possible corrpution"
	merge  1:1  companyid year using "selling.dta"
	drop _merge
	egen ETC1=rowtotal(selling_ETC1 admin_ETC1)
	egen ETC2=rowtotal(selling_ETC2 admin_ETC2)
	egen ETC3=rowtotal(selling_ETC3 admin_ETC3)
	label var ETC1   "Business Entertainment Fee  + Travel and Transportation Fee"
	label var ETC2   "Business Entertainment Fee  + Travel and Transportation Fee+ Car Expense "
	label var ETC3   "Total possible corrpution"
	
	
	save ETC.dta,replace	
	
	
	
********************************************************************************
********************************************************************************	
******************  PREPARING SUBSIDIES  ***************************************
********************************************************************************
********************************************************************************	
	
	


*import "SubsidiesdatafromCSMAR"
*Subsidies can be found in CSMAR in the financial footnotes (only available in Chinese)


rename fn05601 GovSubs_Detail
rename fn05602 Subsidy
rename fn05603 Subsidy_lastyear
rename fn05604 Subsidy_Currency


keep if typrep==1
drop typrep
ren stkcd companyid
keep if strmatch(accper,"*-12-31*")  /* only keep annual report (all firms' fiscal year end at December 31 in China) */
gen year=real(substr(accper,1,4))
drop accper
drop datasources
destring companyid, replace float


*Financial support received
gen aux=0
foreach w in 财政贴息 财政扶持金 {
replace aux=1 if strmatch(GovSubs_Detail,"*`w'")
}

replace aux=Subsidy if aux==1
sort companyid year
bysort companyid year: egen temp=sum(aux)
bysort companyid year: egen FinSup=max(temp) /*Total financial support received*/
drop temp
drop aux

*Tax breaks received
gen aux=0
foreach w in 税收返还款 增值税返还 {
replace aux=1 if strmatch(GovSubs_Detail,"*`w'")
}
replace aux=Subsidy if aux==1

sort companyid year
bysort companyid year: egen temp=sum(aux)
bysort companyid year: egen TaxBreak=max(temp) /*Total tax breaks received*/
drop temp
drop aux

*Total subsidies recieved
drop if strmatch(GovSubs_Detail,"*合计*") /* drop the total  */
sort companyid year
bysort companyid year: egen temp=sum(Subsidy)
bysort companyid year: egen TotalSubsidy=max(temp)
drop temp
drop Subsidy

label var TotalSubsidy "Total subsidies"
label var FinSup "Government financial aid"
label var TaxBreak "Tax refunds"

duplicates drop companyid year, force

save "Prep_Subsidies.dta", replace
	
	
	
********************************************************************************
********************************************************************************	
******************   MERGING ALL DATA    ***************************************
***********  (Accounting, subsidies, ETCs & Connections)  **********************
********************************************************************************
********************************************************************************		
	

use "ConnectionsChina_Board" , clear

	ren id_com companyid
	xtset companyid year
	bysort companyid: egen Connect3=sum(DummyConnEduc3)
	bysort companyid: egen Connect1=sum(DummyConnEduc1)
	bysort companyid: egen Count3=count(DummyConnEduc3)
	bysort companyid: egen Count1=count(DummyConnEduc1)

	
	duplicates drop 
	save Treat_Board.dta,replace	

	/* data cleaning */

		use accounting.dta,clear
		merge  m:1  companyid year using "Treat_Board.dta"
		drop  if _merge==2
		drop _merge
		
		merge m:1 companyid year using "Prep_Subsidies.dta"
		drop _merge

		sort companyid year
		merge  m:1  companyid year using "ETC.dta"
		drop _merge
	
		sort companyid year
		merge 1:1 companyid year using "taxavodidance.dta"
		drop _mer
		
		label var ETR1 "Tax income to total profits"
		label var ETR2 "Tax income to operating cash flow"
		label var METR1 "marginal effective tax rate = ETR1 to legal tax rate"
		label var METR2 "marginal effective tax rate = ETR2 to legal tax rate"
		label var CashETR "cash effective tax rate(cash tax income to total profits)"
		label var AETR "Average ETR1 from year t-2 to year t"
		label var DD_BTD "BTD excluded impact of individual effect and earnings management, by Desai and Dharmapala(Desai & Dharmapala 2009)"
		label var Shelter "Probability to has a tax shelter, based on Wilson’s (2009) tax sheltering model"
		label var LRETR "Long-term effective tax rate (total tax expense from year t-4 to year t, dividing the total profits from year t-4 to year t)"
		label var BTDFACTOR "Principal component of BTD DDBTD DTAX, following Kim and Zhang (2011)"
		
		merge  1:1  companyid year using "employee_capital.dta"
		drop _merge
		

		/* Dependent variable*/
		*Data on Interest Expenses can be found in CSMAR in the financial footnotes (only available in Chinese)
	
		sort companyid year
		gen Cost_Debt=当年利息支出/负债合计 	/* the ratio of total interest payment to total debts */
		gen LCost_Debt=L.当年利息支出/L.负债合计		
		gen Subsidy = 政府补助/营业收入 /* ratio of gov. subsidies to operating revenue */
		gen Subs_ZERO = Subsidy
		replace Subs_ZERO = 0 if missing(政府补助)
		gen LSubsidy = L.Subsidy
		ren TotalSubsidy TotalSubsidy_plain
		gen TotalSubsidy=TotalSubsidy_plain/L.营业收入
		ren FinSup FinSup_plain
		gen FinSup=FinSup_plain/L.营业收入
		gen deltaSubs = Subsidy - LSubsidy
		ren TaxBreak TaxBreak_plain
		gen TaxBreak = TaxBreak_plain/L.营业收入
		gen TaxBreak_alt = TaxBreak_plain/营业收入
		
		replace TaxBreak = TaxBreak*100
		replace TaxBreak_alt = TaxBreak_alt*100
		
		
		
	/* Independent variable */
	
		xtset companyid year
		gen Post=(year>2012)
		
		gen LDummyConnEduc3 = L.DummyConnEduc3
		gen L2DummyConnEduc3 = L.LDummyConnEduc3
		gen LDummyConnEduc1 = L.DummyConnEduc1
		foreach w in LDummyConnEduc3 LDummyConnEduc1 {
		gen `w'xPost=`w'*Post
		}
		
	
		
	/* Control Variables */
	/*Control variables were taken from different CSMAR packages: 
	- Financial Statements (Balance Sheet, Income Statement,Statement of Cash Flows - Direct Method) 
	- Financial Indices (Earning Capacity Analysis, Growth Capability, Solvency, 
	Relative Value Index, Ratio Structure)
	- IPO A-shares (Company Profile) 
	- Equity nature 
	- Special Treatment and Particular Transfer (Basic Info)	
	*/
	
		gen Assets = 资产总计
		gen ROA=总资产净利润率（roa）a  /* ROA */
		gen LROA = L.ROA
		gen Growth=营业收入增长率b /* sale growth rate */
			replace Growth = growth_v1 if missing(Growth)
		gen LGrowth = L.Growth
		gen Leverage=资产负债率 /* leverage */
		gen LLeverage = L.Leverage
		gen TobinQ = 托宾q值a /* Tobin Q */
		gen LTobinQ = L.TobinQ
		sort companyid year
		gen Cash_holding=现金资产比率 /* Cash ratio */
		gen LCash_holding = L.Cash_holding
		gen ipoyear=year(上市日期)
		gen Firm_Age=year-ipoyear /* Firm age */
		gen LFirm_Age = L.Firm_Age
		gen Capex=购建固定资产无形资产和其他长期资产支付的现金/资产总计  /* capital expenditure to total assets */
		gen LCapex = L.Capex
		gen Size=log(资产总计) /* total assets */
		gen LSize = L.Size
		gen State=1 if strmatch(股权性质,"*国*")  /* judge whether the firm is SOE firm  */
		replace State=0 if State==. & 股权性质~=""
		gen OpRev = 营业收入/资产总计   /* Sales to total assets */
		gen LOpRev = L.OpRev
		gen lnboardsize = ln(boardsize)
		gen Llnboardsize = L.lnboardsize
		gen Lboardsize = L.boardsize
		gen Lboardmean_age = L.boardmean_age
		gen Ldualboard = L.dualboard
		gen Lbusydir = L.busydir
		gen Lboard_gender = L.board_gender
		gen Lboard_indratio = L.board_indratio

		replace ETC2=ETC2/营业收入 /*Here, we normalize ETC by total operating revenue */
		gen LETC2 = L.ETC2
		gen ETC2xPost = ETC2*Post
		gen LETC2xPost = LETC2*Post
		gen ConnEduc3XETC2 = DummyConnEduc3*ETC2
		encode province, gen(provinceid)
		gen LConnEduc3XLETC2 = LDummyConnEduc3*LETC2 
		gen industry=substr(行业代码,1,2)
		encode industry,gen(industryid)
			
		
		
		replace LETC2 = 0 if missing(LETC2)
		replace ETC2 = 0 if missing(ETC2)
		replace LConnEduc3XLETC2 = 0 if missing(LConnEduc3XLETC2)
		
	
		replace NumConnEduc3 = 0 if missing(NumConnEduc3)
		replace LNumConnEduc3 = 0 if missing(LNumConnEduc3)
		
		replace dummy_top5 = 0 if missing(dummy_top5)
		replace dummy_top10 = 0 if missing(dummy_top10)
	
		gen ratioConnEduc3 = NumConnEduc3 / Number_of_directors
		replace ratioConnEduc3 = NumConnEduc3 / boardsize if missing(ratioConnEduc3)
		replace ratioConnEduc3 = 0 if missing(ratioConnEduc3)
		gen LratioConnEduc3 = LNumConnEduc3 / L.Number_of_directors
		replace LratioConnEduc3 = LNumConnEduc3 / Lboardsize if missing(LratioConnEduc3)
		replace LratioConnEduc3 = 0 if missing(LratioConnEduc3)

		
		gen LDummyConnEduc3_zhou = L.DummyConnEduc3_zhou
		gen LDummyConnEduc3_zhou_full = L.DummyConnEduc3_zhou_full
		gen LDummyConnEduc3_bo = L.DummyConnEduc3_bo
		gen LDummyConnEduc3_bo_full = L.DummyConnEduc3_bo_full
		gen LDummyConnEduc3_sun = L.DummyConnEduc3_sun
		gen LDummyConnEduc3_sun_full = L.DummyConnEduc3_sun_full
		gen LDummyConnEduc3_xu = L.DummyConnEduc3_xu
		gen LDummyConnEduc3_xu_full = L.DummyConnEduc3_xu_full
		gen LDummyConnEduc3_guo = L.DummyConnEduc3_guo
		gen LDummyConnEduc3_guo_full = L.DummyConnEduc3_guo_full
		gen LDummyConnEduc3_disgrace = L.DummyConnEduc3_disgrace
		gen LDummyConnEduc3_disgrace_full = L.DummyConnEduc3_disgrace_full
		gen LDummyConnEduc3_5disgrace = L.DummyConnEduc3_5disgrace
		gen LDummyConnEduc3_disgrace_5full = L.DummyConnEduc3_disgrace_5full
		
		/*Performance measures*/
		
		gen yit=log(1+营业收入)
		gen lit=log(1+Number_of_employees)
		gen kit=log(1+Assets)
		gen totExlk=cash_for_fixed_longterm+cash_for_goods_service
		gen mit=log(1+totExlk)
		
		reg yit lit kit mit 
		predict yhat
		gen TFP=yit-yhat
		sort companyid year
		gen LTFP=L.TFP
		gen TPFsign=0
		replace TPFsign=1 if TFP>=0
		gen TFPtransf=0
		sum TFP
		replace TFPtransf=TFP-r(min)
		gen LTFPtransf=L.TFPtransf
		gen TFPvar=(TFPtransf-LTFPtransf)/LTFPtransf
		
		
		
		
		gen sales10000=营业收入/10000 /*sales are in ten thousends*/
		gen labor=Number_of_employees/sales10000
		gen Llabor=L.labor
		reghdfe labor Size Growth Intangible, absorb(industryid year)
		predict laborhat
		gen exlabor=labor-laborhat
		gen Lexlabor=L.exlabor
			
		global control LSize LLeverage State LROA LTobinQ
		/* drop the missing variables */
		foreach w in LDummyConnEduc3 Subsidy Cost_Debt $control {
		drop if `w'==.
		}
		
		global control_w LSize LLeverage LCash_holding LGrowth LCapex LTobinQ LROA LETC2 Lboard_gender Lboard_indratio 
		winsor2 TotalSubsidy_plain Subsidy Cost_Debt TaxBreak ETR1 ETR1_noDefer ROA Growth Capex Leverage OpRev TobinQ ETC2 $control_w , replace cut(1 99) by(year)
		drop if companyid== 601991  /*This company is an outlier in terms of cost of debt and biases all the results */		
		
		keep if year>=2007 & year<=2017
			
	/*Summary statistics  */

		label var Cost_Debt   		"Cost of Debt"
		label var Subsidy   		"Subsidy"
		label var Firm_Age  		"Firm Age"
		label var Cash_holding   	"Cash Holding"
		label var ETC1 				"ETC1 over operating revenue"
		label var ETC2 				"ETC2 over operating revenue"
		label var ETC3 				"ETC3 over operating revenue"
		label var DummyConnEduc3 	"ConnEduc3"

	
		drop if year<=ipoyear /* drop the data before IPO year and in IPO year */
		drop if substr(行业代码,1,1)=="J"  /* drop the financial industry */
		drop if ST==1 /* drop the special treatment group */
		drop if int(companyid/100000)==2 | int(companyid/100000)==9  /* drop the firms listed in B shares(stock code like 2----- or 9-----)*/
		xtset companyid year
		drop if industry=="" /* drop the industry missing*/
		drop if 营业收入<0 /* drop the opearting revenue less than 0*/
		drop if 资产负债率>1 /* drop the financial leverage over than 1*/
		
			
		
	
			
		
*Now we recover observations by hand-collecting missing data on provinces:

gen province_english=""
replace province_english="anhui" if companyid==153 & provinceid==. /*BBCA Pahrmaceutical: http://en.bbcayy.com/ */
replace province_english="shandong" if companyid==423 & provinceid==. /*Don-E-E-Jiao: https://www.bloomberg.com/profile/company/000423:CH*/
replace province_english="beijing" if companyid==681 & provinceid==. /*Visual China Group: https://www.bloomberg.com/profile/company/000681:CH*/
replace province_english="sichuan" if companyid==731 & provinceid==. /*Sichuan Meifeng Chemical Industry Co., Ltd.: https://www.bloomberg.com/profile/company/000731:CH*/
replace province_english="ningxia" if companyid==982 & provinceid==. /*Ningxia Zhongyin Cashmere Co., Ltd.:https://www.reuters.com/companies/000982.SZ*/
replace province_english="zhejiang" if companyid==2012 & provinceid==./*Zhejiang KAN Specialities Material Co., Ltd.: https://www.bloomberg.com/profile/company/002012:CH*/
replace province_english="zhejiang" if companyid==2020 & provinceid==./*Zhejiang Jingxin Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002020:CH*/
replace province_english="shandong" if companyid==2026  & provinceid==./*Shangdong Weida Machinery Co., Ltd.: https://www.bloomberg.com/profile/company/002026:CH*/
replace province_english="guangdong" if companyid==2031& provinceid==./*Greatoo Intelligent Equipment Inc.: https://www.bloomberg.com/profile/company/002031:CH*/
replace province_english="shanghai" if companyid==2048 & provinceid==./*Ningbo Huaxiang Electronic Co., Ltd.: https://www.bloomberg.com/profile/company/002048:CH*/
replace province_english="zhejiang" if companyid==2085 & provinceid==./*Zhejiang Wanfeng Auto Wheel Co., Ltd.: https://www.bloomberg.com/profile/company/002085:CH*/
replace province_english="henan" if companyid==2087 & provinceid==./*Henan Xinye Textile Co., Ltd.: https://www.bloomberg.com/profile/company/002087:CH*/
replace province_english="hunan" if companyid==2096 & provinceid==./*Hunan Nanling Civil Explosive Equipment Co., Ltd.: https://www.reuters.com/companies/002096.SZ*/
replace province_english="fujian" if companyid==2102 & provinceid==./*Guanfu Holdings Co., Ltd.:https://www.reuters.com/companies/002102.SZ*/
replace province_english="jilin" if companyid==2118 & provinceid==./*Jilin Zixin Pharmaceutical Industrial Co., Ltd.: https://www.bloomberg.com/profile/company/002118:CH*/
replace province_english="zhejiang" if companyid==2126 & provinceid==./*Zhejiang Yinlun Machinery Co., Ltd.: https://www.bloomberg.com/profile/company/002126:CH*/
replace province_english="zhejiang" if companyid==2188 & provinceid==./*Bus Online Co., Ltd.: https://www.bloomberg.com/profile/company/002188:CH*/
replace province_english="zhejiang" if companyid==2266 & provinceid==./*Zhefu Holding Group Co., Ltd.: https://www.reuters.com/companies/002266.SZ*/
replace province_english="shandong" if companyid==2283 & provinceid==./*Tianrun Industry Technology Co., Ltd.: https://www.bloomberg.com/profile/company/002283:CH*/
replace province_english="zhejiang" if companyid==2332 & provinceid==./*Zhejiang Xianju Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002332:CH*/
replace province_english="shandong" if companyid==2366  & provinceid==./*Taihai Manoir Nuclear Equipment Co., Ltd.:https://www.reuters.com/companies/002366.SZ */
replace province_english="guizhou" if companyid==2390 & provinceid==./*Guizhou Xinbang Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002390:CH*/
replace province_english="shandong" if companyid==2408  & provinceid==./*Zibo Qixiang Tengda Chemical Co., Ltd.: https://www.bloomberg.com/profile/company/002408:CH */
replace province_english="sichuan" if companyid==2466 & provinceid==./*Tianqi Lithium Corporation: https://www.bloomberg.com/profile/company/002466:CH */
replace province_english="shandong" if companyid==2470 & provinceid==./*Kingenta Ecological Engineering Group Co., Ltd.: https://www.bloomberg.com/profile/company/002470:CH*/
replace province_english="jiangsu" if companyid==2496 & provinceid==./*Jiangsu Huifeng Bio-Agriculture Co., Ltd.:https://www.bloomberg.com/profile/company/002496:CH */
replace province_english="zhejiang" if companyid==2522 & provinceid==./*Zhejiang Zhongcheng Packing Material Co., Ltd.: https://www.bloomberg.com/profile/company/002522:CH */
replace province_english="henan" if companyid==2536 & provinceid==./*Feilong Auto Components Co.,Ltd.: https://www.bloomberg.com/profile/company/002536:CH */
replace province_english="shandong" if companyid==2545 & provinceid==./*Qingdao East Steel Tower Stock Co., Ltd.: https://www.bloomberg.com/profile/company/002545:CH */
replace province_english="qinghai" if companyid==2646 & provinceid==./*Qinghai Huzhu Barley Wine Co., Ltd.:  https://www.bloomberg.com/profile/company/002646:CH*/
replace province_english="fujian" if companyid==2679  & provinceid==./*Fujian Jinsen Forestry Co., Ltd.: https://www.bloomberg.com/profile/company/002679:CH */
replace province_english="innermongolia" if companyid==2688 & provinceid==./*Jinhe Biotechnology Co., Ltd.: https://www.bloomberg.com/profile/company/002688:CH */
replace province_english="zhejiang" if companyid==2699 & provinceid==./*Meisheng Cultural & Creative Corp., Ltd.: https://www.reuters.com/companies/002699.SZ */
replace province_english="jiangsu" if companyid==300029 & provinceid==./*Jiangsu Huasheng Tianlong Photoelectric Co., Ltd.: https://www.bloomberg.com/profile/company/300029:CH */
replace province_english="zhejiang" if companyid==300069 & provinceid==./* Zhejiang Jinlihua Electric Co., Ltd.: https://www.reuters.com/companies/300069.SZ */
replace province_english="shandong" if companyid==300214 & provinceid==./*Shandong Rike Chemical Co., Ltd.: https://www.bloomberg.com/profile/company/300214:CH */
replace province_english="jiangsu" if companyid==300258 & provinceid==./*Jiangsu Pacific Precision Forging Co., Ltd.: https://www.bloomberg.com/profile/company/300258:CH */
replace province_english="zhejiang" if companyid==300314 & provinceid==./*Ningbo David Medical Device Co., Ltd.: https://www.bloomberg.com/profile/company/ACAMNZ:CH */
replace province_english="shandong" if companyid==600223 & provinceid==./*Lushang Health Industry Development Co.,Ltd.: https://www.reuters.com/companies/600223.SS */
replace province_english="jiangsu" if companyid==600522 & provinceid==./*Jiangsu Zhongtian Technology Co., Ltd.: https://www.bloomberg.com/profile/company/600522:CH */
replace province_english="sichuan" if companyid==600702 & provinceid==./*Shede Spirits Co., Ltd.: https://www.reuters.com/companies/600702.SS */
replace province_english="hubei" if companyid==601311 & provinceid==./*Camel Group Co., Ltd.: https://www.bloomberg.com/profile/company/601311:CH */

count if missing(province_english)

replace province="青海" if province_english=="qinghai"
replace province="上海" if province_english=="shanghai"
replace province="内蒙古" if province_english=="innermongolia"
replace province="北京" if province_english=="beijing"
replace province="吉林" if province_english=="jilin"
replace province="四川" if province_english=="sichuan"
replace province="宁夏" if province_english=="ningxia"
replace province="安徽" if province_english=="anhui"
replace province="山东" if province_english=="shandong"
replace province="广东" if province_english=="guangdong"
replace province="江苏" if province_english=="jiangsu"
replace province="河南" if province_english=="henan"
replace province="浙江" if province_english=="zhejiang"
replace province="湖北" if province_english=="hubei"
replace province="湖南" if province_english=="hunan"
replace province="福建" if province_english=="fujian"
replace province="贵州" if province_english=="guizhou"

count if missing(province)
drop provinceid
encode province, gen(provinceid)
count if missing(provinceid)
save "ChinaConnections_BOARD", replace
		
**********************************************************************
		
		use MatchedData, clear
		
			gen growth_v2 = Growth if Growth<2
			sort year industryid
			by year industryid: egen meangrowth = mean(growth_v2)
			replace LGrowth = meangrowth if missing(LGrowth)
			drop growth_v2 meangrowth
			sort companyid year
			drop if missing(LTobinQ)
		
*gen province_english=""
replace province_english="anhui" if companyid==153 & provinceid==. /*BBCA Pahrmaceutical: http://en.bbcayy.com/ */
replace province_english="shandong" if companyid==423 & provinceid==. /*Don-E-E-Jiao: https://www.bloomberg.com/profile/company/000423:CH*/
replace province_english="beijing" if companyid==681 & provinceid==. /*Visual China Group: https://www.bloomberg.com/profile/company/000681:CH*/
replace province_english="sichuan" if companyid==731 & provinceid==. /*Sichuan Meifeng Chemical Industry Co., Ltd.: https://www.bloomberg.com/profile/company/000731:CH*/
replace province_english="ningxia" if companyid==982 & provinceid==. /*Ningxia Zhongyin Cashmere Co., Ltd.:https://www.reuters.com/companies/000982.SZ*/
replace province_english="zhejiang" if companyid==2012 & provinceid==./*Zhejiang KAN Specialities Material Co., Ltd.: https://www.bloomberg.com/profile/company/002012:CH*/
replace province_english="zhejiang" if companyid==2020 & provinceid==./*Zhejiang Jingxin Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002020:CH*/
replace province_english="shandong" if companyid==2026  & provinceid==./*Shangdong Weida Machinery Co., Ltd.: https://www.bloomberg.com/profile/company/002026:CH*/
replace province_english="guangdong" if companyid==2031& provinceid==./*Greatoo Intelligent Equipment Inc.: https://www.bloomberg.com/profile/company/002031:CH*/
replace province_english="shanghai" if companyid==2048 & provinceid==./*Ningbo Huaxiang Electronic Co., Ltd.: https://www.bloomberg.com/profile/company/002048:CH*/
replace province_english="zhejiang" if companyid==2085 & provinceid==./*Zhejiang Wanfeng Auto Wheel Co., Ltd.: https://www.bloomberg.com/profile/company/002085:CH*/
replace province_english="henan" if companyid==2087 & provinceid==./*Henan Xinye Textile Co., Ltd.: https://www.bloomberg.com/profile/company/002087:CH*/
replace province_english="hunan" if companyid==2096 & provinceid==./*Hunan Nanling Civil Explosive Equipment Co., Ltd.: https://www.reuters.com/companies/002096.SZ*/
replace province_english="fujian" if companyid==2102 & provinceid==./*Guanfu Holdings Co., Ltd.:https://www.reuters.com/companies/002102.SZ*/
replace province_english="jilin" if companyid==2118 & provinceid==./*Jilin Zixin Pharmaceutical Industrial Co., Ltd.: https://www.bloomberg.com/profile/company/002118:CH*/
replace province_english="zhejiang" if companyid==2126 & provinceid==./*Zhejiang Yinlun Machinery Co., Ltd.: https://www.bloomberg.com/profile/company/002126:CH*/
replace province_english="zhejiang" if companyid==2188 & provinceid==./*Bus Online Co., Ltd.: https://www.bloomberg.com/profile/company/002188:CH*/
replace province_english="zhejiang" if companyid==2266 & provinceid==./*Zhefu Holding Group Co., Ltd.: https://www.reuters.com/companies/002266.SZ*/
replace province_english="shandong" if companyid==2283 & provinceid==./*Tianrun Industry Technology Co., Ltd.: https://www.bloomberg.com/profile/company/002283:CH*/
replace province_english="zhejiang" if companyid==2332 & provinceid==./*Zhejiang Xianju Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002332:CH*/
replace province_english="shandong" if companyid==2366  & provinceid==./*Taihai Manoir Nuclear Equipment Co., Ltd.:https://www.reuters.com/companies/002366.SZ */
replace province_english="guizhou" if companyid==2390 & provinceid==./*Guizhou Xinbang Pharmaceutical Co., Ltd.: https://www.bloomberg.com/profile/company/002390:CH*/
replace province_english="shandong" if companyid==2408  & provinceid==./*Zibo Qixiang Tengda Chemical Co., Ltd.: https://www.bloomberg.com/profile/company/002408:CH */
replace province_english="sichuan" if companyid==2466 & provinceid==./*Tianqi Lithium Corporation: https://www.bloomberg.com/profile/company/002466:CH */
replace province_english="shandong" if companyid==2470 & provinceid==./*Kingenta Ecological Engineering Group Co., Ltd.: https://www.bloomberg.com/profile/company/002470:CH*/
replace province_english="jiangsu" if companyid==2496 & provinceid==./*Jiangsu Huifeng Bio-Agriculture Co., Ltd.:https://www.bloomberg.com/profile/company/002496:CH */
replace province_english="zhejiang" if companyid==2522 & provinceid==./*Zhejiang Zhongcheng Packing Material Co., Ltd.: https://www.bloomberg.com/profile/company/002522:CH */
replace province_english="henan" if companyid==2536 & provinceid==./*Feilong Auto Components Co.,Ltd.: https://www.bloomberg.com/profile/company/002536:CH */
replace province_english="shandong" if companyid==2545 & provinceid==./*Qingdao East Steel Tower Stock Co., Ltd.: https://www.bloomberg.com/profile/company/002545:CH */
replace province_english="qinghai" if companyid==2646 & provinceid==./*Qinghai Huzhu Barley Wine Co., Ltd.:  https://www.bloomberg.com/profile/company/002646:CH*/
replace province_english="fujian" if companyid==2679  & provinceid==./*Fujian Jinsen Forestry Co., Ltd.: https://www.bloomberg.com/profile/company/002679:CH */
replace province_english="innermongolia" if companyid==2688 & provinceid==./*Jinhe Biotechnology Co., Ltd.: https://www.bloomberg.com/profile/company/002688:CH */
replace province_english="zhejiang" if companyid==2699 & provinceid==./*Meisheng Cultural & Creative Corp., Ltd.: https://www.reuters.com/companies/002699.SZ */
replace province_english="jiangsu" if companyid==300029 & provinceid==./*Jiangsu Huasheng Tianlong Photoelectric Co., Ltd.: https://www.bloomberg.com/profile/company/300029:CH */
replace province_english="zhejiang" if companyid==300069 & provinceid==./* Zhejiang Jinlihua Electric Co., Ltd.: https://www.reuters.com/companies/300069.SZ */
replace province_english="shandong" if companyid==300214 & provinceid==./*Shandong Rike Chemical Co., Ltd.: https://www.bloomberg.com/profile/company/300214:CH */
replace province_english="jiangsu" if companyid==300258 & provinceid==./*Jiangsu Pacific Precision Forging Co., Ltd.: https://www.bloomberg.com/profile/company/300258:CH */
replace province_english="zhejiang" if companyid==300314 & provinceid==./*Ningbo David Medical Device Co., Ltd.: https://www.bloomberg.com/profile/company/ACAMNZ:CH */
replace province_english="shandong" if companyid==600223 & provinceid==./*Lushang Health Industry Development Co.,Ltd.: https://www.reuters.com/companies/600223.SS */
replace province_english="jiangsu" if companyid==600522 & provinceid==./*Jiangsu Zhongtian Technology Co., Ltd.: https://www.bloomberg.com/profile/company/600522:CH */
replace province_english="sichuan" if companyid==600702 & provinceid==./*Shede Spirits Co., Ltd.: https://www.reuters.com/companies/600702.SS */
replace province_english="hubei" if companyid==601311 & provinceid==./*Camel Group Co., Ltd.: https://www.bloomberg.com/profile/company/601311:CH */

*count if missing(province_english)

replace province="青海" if province_english=="qinghai"
replace province="上海" if province_english=="shanghai"
replace province="内蒙古" if province_english=="innermongolia"
replace province="北京" if province_english=="beijing"
replace province="吉林" if province_english=="jilin"
replace province="四川" if province_english=="sichuan"
replace province="宁夏" if province_english=="ningxia"
replace province="安徽" if province_english=="anhui"
replace province="山东" if province_english=="shandong"
replace province="广东" if province_english=="guangdong"
replace province="江苏" if province_english=="jiangsu"
replace province="河南" if province_english=="henan"
replace province="浙江" if province_english=="zhejiang"
replace province="湖北" if province_english=="hubei"
replace province="湖南" if province_english=="hunan"
replace province="福建" if province_english=="fujian"
replace province="贵州" if province_english=="guizhou"

count if missing(province)
drop provinceid
encode province, gen(provinceid)
count if missing(provinceid)

/*For the matched data, we use the calipmatch command in Stata
(see Michael Stepner & Allan Garland, 2017. "CALIPMATCH: Stata module for caliper matching without replacement," Statistical Software Components S458342, Boston College Department of Economics.) 
We create a matched for  state and private connected companies respectively. The match satisfy the following conditions: 
- Same year and industry
- Minimize the distance of Size and Leverage
*/
save MatchedData, replace

		
		
		
		
	

		
		
		
		
		
		
		